summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--Lib/os.py11
1 files changed, 9 insertions, 2 deletions
diff --git a/Lib/os.py b/Lib/os.py
index 6cdcdfe..4212232 100644
--- a/Lib/os.py
+++ b/Lib/os.py
@@ -2,9 +2,10 @@
# This exports:
# - all functions from either posix or mac, e.g., os.unlink, os.stat, etc.
# - os.path is either module path or macpath
# - os.name is either 'posix' or 'mac'
# - os.curdir is a string representing the current directory ('.' or ':')
+# - os.pardir is a string representing the parent directory ('..' or '::')
# Programs that import and use 'os' stand a better chance of being
# portable between different platforms. Of course, they must then
@@ -12,15 +13,21 @@
# and opendir), and leave all pathname manipulation to os.path
# (e.g., split and join).
+# XXX This will need to distinguish between real posix and MS-DOS emulation
+
try:
from posix import *
name = 'posix'
curdir = '.'
- import path
+ pardir = '..'
+ import posixpath
+ path = posixpath
+ del posixpath
except ImportError:
from mac import *
name = 'mac'
curdir = ':'
+ pardir = '::'
import macpath
path = macpath
del macpath
@@ -2,9 +2,10 @@
# This exports:
# - all functions from either posix or mac, e.g., os.unlink, os.stat, etc.
-# - os.path is either module path or macpath
+# - os.path is either module posixpath or macpath
# - os.name is either 'posix' or 'mac'
# - os.curdir is a string representing the current directory ('.' or ':')